@@ -36,8 +36,8 @@ import math
 import numpy
 
 # hwrt modules
-from . import HandwrittenData
-from . import preprocessing
+from . import HandwrittenData  # Necessary for pickle files
+from . import preprocessing  # Necessary for pickle files
 from . import utils
 
 
@@ -217,10 +217,10 @@ class InterStrokeDistance(object):
         self.filename = prepare_file(filename)
 
     def __repr__(self):
-        return "InstrokeSpeed(%s)" % self.filename
+        return "InterStrokeDistance(%s)" % self.filename
 
     def __str__(self):
-        return "InstrokeSpeed(%s)" % self.filename
+        return "InterStrokeDistance(%s)" % self.filename
 
     def __call__(self, raw_datasets):
         write_file = open(self.filename, "a")
@@ -262,10 +262,10 @@ class TimeBetweenPoints(object):
         self.filename = prepare_file(filename)
 
     def __repr__(self):
-        return "InstrokeSpeed(%s)" % self.filename
+        return "TimeBetweenPoints(%s)" % self.filename
 
     def __str__(self):
-        return "InstrokeSpeed(%s)" % self.filename
+        return "TimeBetweenPoints(%s)" % self.filename
 
     def __call__(self, raw_datasets):
         average_between_points = open("average_time_between_points.txt", "a")
@@ -295,12 +295,12 @@ class TimeBetweenPoints(object):
                     last_point_end = point['time']
             # The recording might only have one point
             if len(times_between_points) > 0:
-                average_between_points.write("%0.2f\n" %
-                                             numpy.average(times_between_points))
+                tmp = times_between_points
+                average_between_points.write("%0.2f\n" % numpy.average(tmp))
             # The recording might only have one stroke
             if len(times_between_strokes) > 0:
-                average_between_strokes.write("%0.2f\n" %
-                                              numpy.average(times_between_strokes))
+                tmp = times_between_strokes
+                average_between_strokes.write("%0.2f\n" % numpy.average(tmp))
         print("\r100%"+"\033[K\n")
         average_between_points.close()
         average_between_strokes.close()
